Glenn Maxwell's unbelievable leave | cricket.com.au
Description: The Brisbane Heat's Ryan Duffield had his second wicket in as many balls when Glenn Maxwell left a ball swinging back into the stumps

Advertisement

Advertisement

#### Video

28 December 2014

KFC T20 BBL|04

# Glenn Maxwell's unbelievable leave

The Brisbane Heat's Ryan Duffield had his second wicket in as many balls when Glenn Maxwell left a ball swinging back into the stumps

## Latest Videos

2:02

CommBank Test Series v India

### Johnson injury opens door for Starc

Left-arm fast bowler says he'll prepare to play if Mitchell Johnson fails to recover from hamstring soreness

0:57

South Africa v West Indies

### Steyn does a Harmy

South Africa fast bowler Dale Steyn bowled one of the worst balls in his career, one that rivals England quick Steve Harmison's Ashes shocker

0:47

KFC T20 BBL|04

### Freddy calls the action from the middle

Is there nothing Andrew Flintoff can't do? Here he commentates the final ball of the Brisbane Heat's innings while batting

Advertisement

Advertisement

Advertisement

##

##